/*
 *  Switch & 7seg-LED Test Program
 *    Input
 *      Clear SW : 0 = Pushed
 *      Count SW : 0 = Pushed
 *    レベルセンス
 *    Output
 *      7seg-LED via SPI ch.0
 *
 *    Compile
 *      cc -o swtest0 swtest0.c out7seg.c -lwiringPi
*/

#include <stdio.h>
#include <stdlib.h>
#include <wiringPi.h> // GPIO 制御用ヘッダ
#include "out7seg.h"

/************************************************************************/

/* GPIO BCM の定義 */
#define SW_CLEAR_PIN  5
#define SW_COUNT_PIN  6

#define SW_CLEAR 2
#define SW_COUNT 1

/* ポートの設定 */
void init_PORT(void)
{
    pinMode(SW_CLEAR, INPUT);
    pullUpDnControl(SW_CLEAR, PUD_OFF);
    pinMode(SW_COUNT, INPUT);
    pullUpDnControl(SW_COUNT, PUD_OFF);

    init_SegLED();
}

/* SWの入力 */
int SW_input()
{
    int sw = 0;
    if (digitalRead(SW_CLEAR_PIN))
        sw |= SW_CLEAR;
    if (digitalRead(SW_COUNT_PIN))
        sw |= SW_COUNT;
    return sw;
}

/************************************************************************/

#define MAX_COUNT 10

main(void)
{
    int sw_cur;                             // スイッチの現在の状態
    int count;                              // カウンタ

    if (wiringPiSetupGpio() == -1) {        // WiringPiの初期化
        fprintf(stderr,"GPIO Setup error\n");
        exit(1);
    }

    init_PORT();                            // ポートの設定
    count = 0;                              // カウンタ初期化

    while (1)                               // 無限ループ
    {
        sw_cur = SW_input();                // スイッチの状態を入力

        if (!(sw_cur & SW_COUNT)) {         // Count SWが押されていて0のとき
            if (++count >= MAX_COUNT)       //   カウントアップし，MAX_COUNTになったら
                count = 0;                  //     0に戻す
//          printf("%d\n", count);          //   カウンタの値を表示
        }

        if (!(sw_cur & SW_CLEAR)) {         // Clear SWが押されていて0のとき
            count = 0;                      //   カウンタ初期化
//          printf("Clear %d\n", count);    //   カウンタの値を表示
        }
        SegLED_disp(count, 0);              // 7seg LEDに表示
    }
}
